@@ -1,10 +1,5 @@
 var NAVTREEINDEX3 =
 {
-"group__codec.html#gad4bd9523583de840a940dbedb6a34d58":[12,0,5],
-"group__codec.html#gad93e9ac33d1a9153bbea517a98260041":[12,0,7],
-"group__codec.html#gad9b5552eb4fbe66c016d177b1d04e160":[12,0,45],
-"group__codec.html#gadcd30e5b2e9f025d38c733d90c0b651c":[12,0,15],
-"group__codec.html#gadf9e173c9e02788a9999399edab20a02":[12,0,29],
 "group__codec.html#gae53eac1526df7270f920853dae492b1d":[12,0,50],
 "group__codec.html#gaf35aecefb8133a5474d0068119e6182c":[12,0,18],
 "group__codec.html#gaf452ede024bf9a378fa66443494070ba":[12,0,20],
@@ -249,5 +244,10 @@ var NAVTREEINDEX3 =
 "group__rate__control.html#gad9722dabdd6c62b9d2fac0551b83fe89":[12,2,0,2,19],
 "group__rate__control.html#gadfa699be3bda2371d17b7012247be81d":[12,2,0,2,27],
 "group__rate__control.html#gadfe05128d22bba397120763fe132c867":[12,2,0,2,6],
-"group__rate__control.html#gae256aad9cb7fbcb22b6944d5b3053a1f":[12,2,0,2,17]
+"group__rate__control.html#gae256aad9cb7fbcb22b6944d5b3053a1f":[12,2,0,2,17],
+"group__rate__control.html#gae9eddc0e6469d28bd0429c03efe97544":[12,2,0,2,12],
+"group__rate__control.html#gaf3b990f88a7036986750f9ae344129e9":[12,2,0,2,23],
+"group__rate__control.html#gaf73c75a80818ad2b556f6d86a7e71c5f":[12,2,0,2,13],
+"group__speed__features.html":[12,2,0,0],
+"group__speed__features.html#ga375df45f353341a53823feb529182b2a":[12,2,0,0,0]
 };
