@@ -1,12 +1,5 @@
 var NAVTREEINDEX7 =
 {
-"structLAYER__CONTEXT.html":[12,2,10,0],
-"structLAYER__CONTEXT.html#a1d897dac3039f8c548df285f6c59b9a9":[12,2,10,0,2],
-"structLAYER__CONTEXT.html#a4ff0c1a06b8fd96f5ff37bf2aa98b9d3":[12,2,10,0,0],
-"structLAYER__CONTEXT.html#a5aa14c130d362a8f686211b292b5bbed":[12,2,10,0,4],
-"structLAYER__CONTEXT.html#a69214df6581b337c578998038451c57a":[12,2,10,0,5],
-"structLAYER__CONTEXT.html#a73f7772f35adac06e7f0a0fa76e3e2e8":[12,2,10,0,3],
-"structLAYER__CONTEXT.html#aa271730c1338c86af854946a694329bc":[12,2,10,0,8],
 "structLAYER__CONTEXT.html#ab1a9c759d6a221c6acafcde147e08a7b":[12,2,10,0,7],
 "structLAYER__CONTEXT.html#ac84886e42f345445136e78d701fec643":[12,2,10,0,6],
 "structLAYER__CONTEXT.html#af1c6b09cc85e7314d989aae83a7b28d5":[12,2,10,0,1],
@@ -249,5 +242,12 @@ var NAVTREEINDEX7 =
 "structRateControlCfg.html#ac23a9405f6062c40865f8d663f0d9988":[13,0,113,7],
 "structRateControlCfg.html#ac5449b521f590df024dee3d084a487a0":[13,0,113,17],
 "structRateControlCfg.html#ace800761e330b4232c9de58c0999b32e":[13,0,113,15],
-"structRateControlCfg.html#ad16374c14dc126a48203218eb37e4ec9":[13,0,113,6]
+"structRateControlCfg.html#ad16374c14dc126a48203218eb37e4ec9":[13,0,113,6],
+"structRateControlCfg.html#ad68d50f3297bc20648f9875ae3804fe4":[13,0,113,0],
+"structRateControlCfg.html#ae14bcf62c04a99909d185c14dffdfbba":[13,0,113,13],
+"structRateControlCfg.html#ae47c57035f349625892846ecaa963f7a":[13,0,113,10],
+"structRateControlCfg.html#ae4e7c69ac7953cd0b3a163c78ab63b10":[13,0,113,3],
+"structRateControlCfg.html#ae85fef9531436afe2e0cff3534ca5aa2":[13,0,113,1],
+"structRateControlCfg.html#af6b5df24567a9e027c89453d0ad69c8e":[13,0,113,14],
+"structRefFrameDistanceInfo.html":[13,0,114]
 };
