@@ -1,12 +1,5 @@
 var NAVTREEINDEX9 =
 {
-"structaom__codec__enc__cfg.html#a61837750dea1315878b53e2767d9716b":[12,0,1,5,51],
-"structaom__codec__enc__cfg.html#a623802304a377237ec6df7ae31984655":[12,0,1,5,35],
-"structaom__codec__enc__cfg.html#a630b9cb2fa79022a7b63cb0bed7e5fcb":[12,0,1,5,34],
-"structaom__codec__enc__cfg.html#a64d3517b2cef17cd57ec3f659ad0f2ab":[12,0,1,5,21],
-"structaom__codec__enc__cfg.html#a6c25595e7dfcdf3229c3f66c91224fcc":[12,0,1,5,32],
-"structaom__codec__enc__cfg.html#a715cb435d6eaca88eab71a763af3d8ec":[12,0,1,5,2],
-"structaom__codec__enc__cfg.html#a71628d182062afe21a884fa584714b74":[12,0,1,5,5],
 "structaom__codec__enc__cfg.html#a71d97f2a1ff3850955c50705104ac54a":[12,0,1,5,44],
 "structaom__codec__enc__cfg.html#a76a27f44cded1516803a776a0a7e9038":[12,0,1,5,8],
 "structaom__codec__enc__cfg.html#a7859761b70f5a44005dfd776e7c2f79d":[12,0,1,5,50],
@@ -249,5 +242,12 @@ var NAVTREEINDEX9 =
 "structcfg__options.html#a331cfdad126347666de6587dc29fc38e":[12,0,1,4,4],
 "structcfg__options.html#a376c8f8a0b78775ef4e12d985ef894bf":[12,0,1,4,11],
 "structcfg__options.html#a5289c2559ca448ca8a9acbe07d21640c":[12,0,1,4,9],
-"structcfg__options.html#a57181110117a0c481d55673fa6fe9006":[12,0,1,4,6]
+"structcfg__options.html#a57181110117a0c481d55673fa6fe9006":[12,0,1,4,6],
+"structcfg__options.html#a573d9454ec8f7f909b469c210d2dbbdf":[12,0,1,4,24],
+"structcfg__options.html#a58e0d12bcf3cb23a60e79944c835bff2":[12,0,1,4,3],
+"structcfg__options.html#a5e9060bdbe5be1de328c65138bff1138":[12,0,1,4,21],
+"structcfg__options.html#a6015b43668ab3cd208a3b92441e26f1f":[12,0,1,4,32],
+"structcfg__options.html#a6075bf485c4bc21e401b8ece1cb8c5dc":[12,0,1,4,34],
+"structcfg__options.html#a6312b3c77aeeb02ffb2860a147649621":[12,0,1,4,17],
+"structcfg__options.html#a689825832352b0a5e1b1191ecaa39e91":[12,0,1,4,2]
 };
